c
c adc channel info common
c
c one readout cell (adc channel) can be identified by:
c
c - "adc channel system" 
c    with index ic
c
c - "database system" 
c    with indices i_mod = module number
c                 i_seg = segment (family) number
c                 i_pad = pad number (odd/even scheme)
c
c - "physics system"
c    with indices i_eta = tower eta label
c                 i_phi = tower phi label
c                 i_z   = tower depth number
c
c parameters
c i_adc_dim       max number of adc channels (for array dimension)
c i_adc_max       max adc value
c
c i_mod_max       max number of modules       (for array dimension)
c i_seg_max       max number of segments      (for array dimension)
c i_pad_max       max number of pads          (for array dimension)
c
c i_eta_max       max number of towers in eta (for array dimension)
c i_phi_max       max number of towers in phi (for array dimension)
c i_z_max         max number of readout depth (for array dimension)
c
c variables
c
c i_adc_used      actual highest adc channel number used
c
c i_mod_used      actual number of modules used
c i_seg_used      actual number of segments used
c i_pad_used      actual number of pads used
c
c i_eta_used      actual number of towers in eta used
c i_phi_used      actual number of tower in phi used
c i_z_used        actual number of tower depths used
c 
c geometry correspondence tables 
c ictodb(ic,3)                  "adc channel system" to "database system"
c ictoph(ic,3)                  "adc channel system" to "physics system"
c i_dbtoic(i_mod,i_seg,i_pad)   "database system" to "adc channel system"
c i_phtoic(i_eta,i_phi,i_z)     "physics system"  to "adc channel system"
c
c adc channels
c i_adc_val(ic)                adc values   "database system" 
c i_adc_db(i_mod,i_seg,i_pad)  adc values   "physics system" 
c i_adc_ph(i_eta,i_phi,i_z)    adc values   "physics system"
c
c adc_ped(ic)     adc pedestal (real)
c adc_rms(ic)     adc pedestal rms (real)
c
c adc_cal(ic,i)   i = 1,4 for the 4 calibration parameters
c                   = 5 for the calibration flag  
c                      (1=good, 2=bad fit, 3=dead)
c
c
c It is assumed that only 16 pads are connected per segment
c
c note that    1 <= ic <= 256  are high gain  (*4)  gain index = 0
c            257 <= ic <= 512  are low  gain        gain index = 1
c but here only the high gain are considered.
c
c
c MAY 1996 TESTS
c Module present:  Front CDN/USA module
c we have the following ranges of indices:
c
c   ic      i_mod  i_seg  i_pad      i_eta  i_phi  i_z
c  [1,16]     1      1   [1,16]      [1,8]  [1,2]   1
c [17,32]     1      2   [1,16]      [2,9]  [1,2]   2
c [33,48]     1      3   [1,16]     [3,10]  [1,2]   3
c
c note that the only values of ic that correspond to a channel are
c  1 <= ic <= 48 
c
c we therefore have the following values:
c
c i_mod_used = 1       i_eta_used = 10
c i_seg_used = 3       i_phi_used = 2
c i_pad_used = 16      i_z_used   = 3
c
c
c JULY 1996 TESTS
c Modules present:  Front CDN/USA module  (i_mod=1 and i_seg=[1,3])
c                   Front Russia module   (i_mod=2 and i_seg=[1,3])
c                   Back Russia module    (i_mod=1 and i_seg=[4,5])
c note that the back module was positionned in the middle in phi
c note that the CDN/USA module is at high phi
c note that the back module is logically module 1, as for the CDN/USA module
c
c we have the following ranges of indices:
c
c     ic        i_mod  i_seg  i_pad      i_eta  i_phi  i_z
c    [1,16]       1      1   [1,16]      [1,8]  [3,4]   1
c   [17,32]       1      2   [1,16]      [2,9]  [3,4]   2
c   [33,48]       1      3   [1,16]     [3,10]  [3,4]   3
c   [49,64]       1      4   [1,16]     [4,11]  [2,3]   4
c   [65,80]       1      5   [1,16]     [5,12]  [2,3]   5
c   [81,96]       2      1   [1,16]      [1,8]  [1,2]   1
c  [97,112]       2      2   [1,16]      [2,9]  [1,2]   2
c [113,128]       2      3   [1,16]     [3,10]  [1,2]   3
c
c note that the only values of ic that correspond to a channel are
c  1 <= ic <= 128
c
c we therefore have the following values:
c
c i_mod_used = 2       i_eta_used = 12
c i_seg_used = 5       i_phi_used = 4
c i_pad_used = 16      i_z_used   = 5
c
c
c CORRESPONDENCE TABLES 
c the following correspondence tables are filled by hec_geo.f
c returned values are 0 if the corresponding channel is not 
c connected or does not exist
c
c from "adc channel system" to "database system"
c ictodb(ic, i_coor) = i_mod if i_coor=1    
c                    = i_seg if i_coor=2 
c                    = i_pad if i_coor=3
c
c from "database system" to "adc channel system"
c dbtoic(i_mod, i_seg, i_pad) = ic 
c
c from "adc channel system" to "physics system" 
c ictoph(ic, i_coor) = i_eta if i_coor=1
c                    = i_phi if i_coor=2
c                    = i_z   if i_coor=3
c
c from "physics system" to "adc channel system"
c phtoic(i_eta, i_phi, i_z)   = ic 
c 
      integer i_adc_dim
      parameter (i_adc_dim = 160) !max adc channel number
      integer adcmax
      parameter (adcmax = 4095) !max adc value
c
      integer i_mod_max, i_seg_max, i_pad_max
      parameter (i_mod_max = 2)
      parameter (i_seg_max = 5)
      parameter (i_pad_max = 16)
c
      integer i_eta_max, i_phi_max, i_z_max
      parameter (i_eta_max = 12)
      parameter (i_phi_max = 4)
      parameter (i_z_max   = 5)
c
      integer i_adc_used        !actual highest adc channel number used
c
      integer i_mod_used        !actual number of modules used
      integer i_seg_used        !actual number of segments (family) used
      integer i_pad_used        !actual number of pads used
c
      integer i_eta_used        !actual number of towers in eta used
      integer i_phi_used        !actual number of tower in phi used
      integer i_z_used          !actual number of tower depths used
c
      integer i_adc_val(1:i_adc_dim)
      integer i_adc_db(1:i_mod_max, 1:i_seg_max, 1:i_pad_max)
      integer i_adc_ph(1:i_eta_max, 1:i_phi_max, 1:i_z_max)
      real adc_ped(1:i_adc_dim)
      real adc_rms(1:i_adc_dim)
c
      real adc_cal(1:i_adc_dim, 5)
c
      integer ictodb(1:i_adc_dim, 3)
      integer ictoph(1:i_adc_dim, 3)
      integer dbtoic(1:i_mod_max, 1:i_seg_max, 1:i_pad_max)
      integer phtoic(1:i_eta_max, 1:i_phi_max, 1:i_z_max)
c
      common /padcom/ i_adc_used,
     +                i_mod_used,
     +                i_seg_used,
     +                i_pad_used,
     +                i_eta_used,
     +                i_phi_used,
     +                i_z_used,
     +                ictodb,
     +                ictoph,
     +                dbtoic,
     +                phtoic,
     +                i_adc_val,
     +                i_adc_db,
     +                i_adc_ph,
     +                adc_ped,
     +                adc_rms,
     +                adc_cal
c
